@@ -11,11 +11,11 @@ class ContactForm(forms.Form):
     content = forms.CharField(widget=forms.Textarea())
 
     def send(self, site_email):
+        message = Message.objects.create(**self.cleaned_data)
         email_message = EmailMessage(
             self.cleaned_data['subject'],
-            render_to_string("aldryn_contact/email.txt", {'data': self.cleaned_data}),
+            render_to_string("aldryn_contact/email.txt", {'message': message}),
             site_email,
             [site_email],
             headers={'Reply-To': self.cleaned_data['email']})
-        Message.objects.create(**self.cleaned_data)
         email_message.send(fail_silently=True)
